@@ -20,12 +20,16 @@
 
 #include "content.h"
 
-#include "surface.h"
-
+#include <stdlib.h>
 #define WLR_USE_UNSTABLE
 #include <wlr/types/wlr_compositor.h>
 #undef WLR_USE_UNSTABLE
 
+#include "input.h"
+#include "surface.h"
+#include "window.h"
+
+
 /* == Declarations ========================================================= */
 
 static void _wlmtk_content_element_get_dimensions(
@@ -51,20 +55,19 @@ static const wlmtk_element_vmt_t _wlmtk_content_element_vmt = {
 /* ------------------------------------------------------------------------- */
 bool wlmtk_content_init(
     wlmtk_content_t *content_ptr,
-    wlmtk_element_t *element_ptr,
-    wlmtk_env_t *env_ptr)
+    wlmtk_element_t *element_ptr)
 {
     BS_ASSERT(NULL != content_ptr);
-    memset(content_ptr, 0, sizeof(wlmtk_content_t));
+    *content_ptr = (wlmtk_content_t){};
 
-    if (!wlmtk_container_init(&content_ptr->super_container, env_ptr)) {
+    if (!wlmtk_container_init(&content_ptr->super_container)) {
         return false;
     }
     content_ptr->orig_super_element_vmt = wlmtk_element_extend(
         &content_ptr->super_container.super_element,
         &_wlmtk_content_element_vmt);
 
-    if (!wlmtk_container_init(&content_ptr->popup_container, env_ptr)) {
+    if (!wlmtk_container_init(&content_ptr->popup_container)) {
         wlmtk_content_fini(content_ptr);
         return false;
     }
@@ -103,7 +106,7 @@ void wlmtk_content_fini(
             &content_ptr->super_container, content_ptr->element_ptr);
         content_ptr->element_ptr = NULL;
     }
-    memset(content_ptr, 0, sizeof(wlmtk_content_t));
+    *content_ptr = (wlmtk_content_t){};
 }
 
 /* ------------------------------------------------------------------------- */
@@ -339,9 +342,9 @@ wlmtk_fake_content_t *wlmtk_fake_content_create(
     if (NULL == fake_content_ptr) return NULL;
     fake_content_ptr->fake_surface_ptr = fake_surface_ptr;
 
-    if (!wlmtk_content_init(&fake_content_ptr->content,
-                            wlmtk_surface_element(&fake_surface_ptr->surface),
-                            NULL)) {
+    if (!wlmtk_content_init(
+            &fake_content_ptr->content,
+            wlmtk_surface_element(&fake_surface_ptr->surface))) {
         wlmtk_fake_content_destroy(fake_content_ptr);
         return NULL;
     }
@@ -424,12 +427,13 @@ void test_init_fini(bs_test_t *test_ptr)
     struct wlr_box box;
 
     wlmtk_fake_surface_t *fs_ptr = wlmtk_fake_surface_create();
-    BS_ASSERT(NULL != fs_ptr);
+    BS_TEST_VERIFY_NEQ_OR_RETURN(test_ptr, NULL, fs_ptr);
     wlmtk_fake_content_t *fake_content_ptr = wlmtk_fake_content_create(fs_ptr);
-    BS_ASSERT(NULL != fake_content_ptr);
+    BS_TEST_VERIFY_NEQ_OR_RETURN(test_ptr, NULL, fake_content_ptr);
 
     wlmtk_element_t *element_ptr = wlmtk_content_element(
         &fake_content_ptr->content);
+    wlmtk_element_set_visible(element_ptr, true);
 
     // Initial size is zero.
     box = wlmtk_element_get_dimensions_box(element_ptr);
@@ -439,9 +443,10 @@ void test_init_fini(bs_test_t *test_ptr)
     BS_TEST_VERIFY_EQ(test_ptr, 0, box.height);
 
     // Pointer motion, should report to not be within the content.
+    wlmtk_pointer_motion_event_t e = { .x = 10, .y = 10 };
     BS_TEST_VERIFY_FALSE(
         test_ptr,
-        wlmtk_element_pointer_motion(element_ptr, 10, 10, 0));
+        wlmtk_element_pointer_motion(element_ptr, &e));
 
     // Request & commit a sensible size, verifies the content reports it.
     wlmtk_content_request_size(&fake_content_ptr->content, 200, 100);
@@ -455,7 +460,7 @@ void test_init_fini(bs_test_t *test_ptr)
     // Pointer motion shouuld now report to be within the content.
     BS_TEST_VERIFY_TRUE(
         test_ptr,
-        wlmtk_element_pointer_motion(element_ptr, 10, 10, 0));
+        wlmtk_element_pointer_motion(element_ptr, &e));
 
     wlmtk_fake_content_destroy(fake_content_ptr);
     wlmtk_fake_surface_destroy(fs_ptr);
@@ -466,10 +471,10 @@ void test_init_fini(bs_test_t *test_ptr)
 void test_set_clear_element(bs_test_t *test_ptr)
 {
     wlmtk_fake_surface_t *fs_ptr = wlmtk_fake_surface_create();
-    BS_ASSERT(NULL != fs_ptr);
+    BS_TEST_VERIFY_NEQ_OR_RETURN(test_ptr, NULL, fs_ptr);
 
     wlmtk_content_t content;
-    BS_TEST_VERIFY_TRUE(test_ptr, wlmtk_content_init(&content, NULL, NULL));
+    BS_TEST_VERIFY_TRUE(test_ptr, wlmtk_content_init(&content, NULL));
     BS_TEST_VERIFY_EQ(test_ptr, NULL, content.element_ptr);
 
     wlmtk_content_set_element(
@@ -494,22 +499,20 @@ void test_add_remove_popup(bs_test_t *test_ptr)
     wlmtk_content_t parent, popup;
 
     wlmtk_fake_surface_t *fs0_ptr = wlmtk_fake_surface_create();
+    BS_TEST_VERIFY_NEQ_OR_RETURN(test_ptr, NULL, fs0_ptr);
     wlmtk_fake_surface_commit_size(fs0_ptr, 100, 10);
     wlmtk_fake_surface_t *fs1_ptr = wlmtk_fake_surface_create();
+    BS_TEST_VERIFY_NEQ_OR_RETURN(test_ptr, NULL, fs1_ptr);
     wlmtk_fake_surface_commit_size(fs1_ptr, 200, 20);
 
     BS_TEST_VERIFY_TRUE(
         test_ptr,
         wlmtk_content_init(
-            &parent,
-            wlmtk_surface_element(&fs0_ptr->surface),
-            NULL));
+            &parent, wlmtk_surface_element(&fs0_ptr->surface)));
     BS_TEST_VERIFY_TRUE(
         test_ptr,
         wlmtk_content_init(
-            &popup,
-            wlmtk_surface_element(&fs1_ptr->surface),
-            NULL));
+            &popup, wlmtk_surface_element(&fs1_ptr->surface)));
 
     wlmtk_element_set_visible(wlmtk_content_element(&parent), true);
     wlmtk_element_set_visible(wlmtk_content_element(&popup), true);
@@ -558,21 +561,20 @@ void test_add_remove_wlmtk_popup(bs_test_t *test_ptr)
     wlmtk_popup_t popup;
 
     wlmtk_fake_surface_t *fs0_ptr = wlmtk_fake_surface_create();
+    BS_TEST_VERIFY_NEQ_OR_RETURN(test_ptr, NULL, fs0_ptr);
     wlmtk_fake_surface_commit_size(fs0_ptr, 100, 10);
     wlmtk_fake_surface_t *fs1_ptr = wlmtk_fake_surface_create();
+    BS_TEST_VERIFY_NEQ_OR_RETURN(test_ptr, NULL, fs1_ptr);
     wlmtk_fake_surface_commit_size(fs1_ptr, 200, 20);
 
     BS_TEST_VERIFY_TRUE(
         test_ptr,
         wlmtk_content_init(
-            &content,
-            wlmtk_surface_element(&fs0_ptr->surface),
-            NULL));
+            &content, wlmtk_surface_element(&fs0_ptr->surface)));
 
     BS_TEST_VERIFY_TRUE(
         test_ptr,
-        wlmtk_popup_init(&popup, NULL,
-                         wlmtk_surface_element(&fs1_ptr->surface)));
+        wlmtk_popup_init(&popup, wlmtk_surface_element(&fs1_ptr->surface)));
 
     wlmtk_element_set_visible(wlmtk_content_element(&content), true);
     wlmtk_element_set_visible(wlmtk_popup_element(&popup), true);
