@@ -18,12 +18,27 @@
  * limitations under the License.
  */
 
-#include "xdg_shell.h"
-
-#include "tl_menu.h"
-#include "xdg_popup.h"
+#include "xdg_toplevel.h"
 
+#include <libbase/libbase.h>
+#include <stdbool.h>
+#include <stdint.h>
+#include <stdlib.h>
+#include <wayland-server-core.h>
+#include <wayland-server-protocol.h>
+#include <wayland-server.h>
+#include <wayland-util.h>
+#define WLR_USE_UNSTABLE
+#include <wlr/types/wlr_compositor.h>
+#include <wlr/util/box.h>
 #include <wlr/version.h>
+#undef WLR_USE_UNSTABLE
+
+#include "config.h"
+#include "server.h"
+#include "tl_menu.h"
+#include "toolkit/toolkit.h"
+#include "xdg_popup.h"
 
 /* == Declarations ========================================================= */
 
@@ -166,7 +181,7 @@ wlmtk_window_t *wlmtk_window_create_from_xdg_toplevel(
         &surface_ptr->super_content,
         &server_ptr->style.window,
         &server_ptr->style.menu,
-        server_ptr->env_ptr);
+        server_ptr->wlr_seat_ptr);
     if (NULL == wlmtk_window_ptr) {
         xdg_toplevel_surface_destroy(surface_ptr);
         return NULL;
@@ -207,7 +222,7 @@ xdg_toplevel_surface_t *xdg_toplevel_surface_create(
 
     xdg_tl_surface_ptr->surface_ptr = wlmtk_surface_create(
         wlr_xdg_toplevel_ptr->base->surface,
-        server_ptr->env_ptr);
+        server_ptr->wlr_seat_ptr);
     if (NULL == xdg_tl_surface_ptr->surface_ptr) {
         xdg_toplevel_surface_destroy(xdg_tl_surface_ptr);
         return NULL;
@@ -217,8 +232,7 @@ xdg_toplevel_surface_t *xdg_toplevel_surface_create(
 
     if (!wlmtk_content_init(
             &xdg_tl_surface_ptr->super_content,
-            wlmtk_surface_element(xdg_tl_surface_ptr->surface_ptr),
-            server_ptr->env_ptr)) {
+            wlmtk_surface_element(xdg_tl_surface_ptr->surface_ptr))) {
         xdg_toplevel_surface_destroy(xdg_tl_surface_ptr);
         return NULL;
     }
@@ -226,8 +240,7 @@ xdg_toplevel_surface_t *xdg_toplevel_surface_create(
             &xdg_tl_surface_ptr->super_content,
             &_xdg_toplevel_content_vmt);
 
-    memset(&xdg_tl_surface_ptr->super_content.client, 0,
-           sizeof(wlmtk_util_client_t));
+    xdg_tl_surface_ptr->super_content.client = (wlmtk_util_client_t){};
     wl_client_get_credentials(
         xdg_tl_surface_ptr->surface_ptr->wlr_surface_ptr->resource->client,
         &xdg_tl_surface_ptr->super_content.client.pid,
@@ -459,7 +472,7 @@ void handle_new_popup(
 
     wlmaker_xdg_popup_t *xdg_popup_ptr = wlmaker_xdg_popup_create(
         wlr_xdg_popup_ptr,
-        xdg_tl_surface_ptr->server_ptr->env_ptr);
+        xdg_tl_surface_ptr->server_ptr->wlr_seat_ptr);
     if (NULL == xdg_popup_ptr) {
         wl_resource_post_error(
             wlr_xdg_popup_ptr->resource,
@@ -577,10 +590,10 @@ void handle_toplevel_request_maximize(
         listener_ptr,
         xdg_toplevel_surface_t,
         toplevel_request_maximize_listener);
+
     wlmtk_window_request_maximized(
         xdg_tl_surface_ptr->super_content.window_ptr,
-        !wlmtk_window_is_maximized(
-            xdg_tl_surface_ptr->super_content.window_ptr));
+        xdg_tl_surface_ptr->wlr_xdg_toplevel_ptr->requested.maximized);
 
     // Protocol expects an `ack_configure`. Depending on current state, that
     // may not have been sent throught @ref wlmtk_window_request_maximized,
@@ -603,12 +616,16 @@ void handle_toplevel_request_fullscreen(
     xdg_toplevel_surface_t *xdg_tl_surface_ptr = BS_CONTAINER_OF(
         listener_ptr,
         xdg_toplevel_surface_t,
-        toplevel_request_maximize_listener);
+        toplevel_request_fullscreen_listener);
+
+    // Sets the requested output. Or NULL, if no preference indicated.
+    wlmtk_window_set_output(
+        xdg_tl_surface_ptr->super_content.window_ptr,
+        xdg_tl_surface_ptr->wlr_xdg_toplevel_ptr->requested.fullscreen_output);
 
     wlmtk_window_request_fullscreen(
         xdg_tl_surface_ptr->super_content.window_ptr,
-        !wlmtk_window_is_fullscreen(
-            xdg_tl_surface_ptr->super_content.window_ptr));
+        xdg_tl_surface_ptr->wlr_xdg_toplevel_ptr->requested.fullscreen);
 
     // Protocol expects an `ack_configure`. Depending on current state, that
     // may not have been sent throught @ref wlmtk_window_request_maximized,
